summaryrefslogtreecommitdiff
path: root/fml/lib
diff options
context:
space:
mode:
authorfukachan <fukachan>2004-05-22 06:19:49 +0000
committerfukachan <fukachan>2004-05-22 06:19:49 +0000
commita523d84b1df056c7e8a63c527f27d7e43f1688e0 (patch)
treec06541365c33b5105457a2b4c1fb9de2c76ab126 /fml/lib
parent2deadbc210314fe9dfbb589b3397be8fc85f5e53 (diff)
downloadfml8-a523d84b1df056c7e8a63c527f27d7e43f1688e0.tar.gz
fml8-a523d84b1df056c7e8a63c527f27d7e43f1688e0.tar.bz2
fml8-a523d84b1df056c7e8a63c527f27d7e43f1688e0.zip
rename variable: $error_* -> $error_mail_*
error_analyzer_day_limit->error_mail_analyzer_day_limit error_analyzer_cache_dir->error_mail_analyzer_cache_dir error_analyzer_cache_type->error_mail_analyzer_cache_type error_analyzer_cache_mode->error_mail_analyzer_cache_mode error_analyzer_cache_size->error_mail_analyzer_cache_size error_analyzer_function_select_list->error_mail_analyzer_function_select_list error_analyzer_function->error_mail_analyzer_function error_analyzer_simple_count_limit->error_mail_analyzer_simple_count_limit
Diffstat (limited to 'fml/lib')
-rw-r--r--fml/lib/FML/Command/Admin/error.pm6
-rw-r--r--fml/lib/FML/Error.pm10
-rw-r--r--fml/lib/FML/Error/Analyze/histgram.pm6
-rw-r--r--fml/lib/FML/Error/Analyze/simple_count.pm6
-rw-r--r--fml/lib/FML/Error/Cache.pm14
5 files changed, 21 insertions, 21 deletions
diff --git a/fml/lib/FML/Command/Admin/error.pm b/fml/lib/FML/Command/Admin/error.pm
index 5dd21cc7..5211e33d 100644
--- a/fml/lib/FML/Command/Admin/error.pm
+++ b/fml/lib/FML/Command/Admin/error.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: error.pm,v 1.11 2004/04/18 05:59:43 fukachan Exp $
+# $FML: error.pm,v 1.12 2004/04/20 03:32:47 fukachan Exp $
#
package FML::Command::Admin::error;
@@ -83,7 +83,7 @@ sub _fmlerror
my ($self, $curproc) = @_;
my $config = $curproc->config();
my $select_list =
- $config->get_as_array_ref('error_analyzer_function_select_list');
+ $config->get_as_array_ref('error_mail_analyzer_function_select_list');
use FML::Error;
my $error = new FML::Error $curproc;
@@ -92,7 +92,7 @@ sub _fmlerror
my $option = $curproc->cui_command_specific_options() || {};
if (defined $option->{ algorithm } && $option->{ algorithm }) {
my $fp = $option->{ algorithm };
- if ($config->has_attribute('error_analyzer_function_select_list',
+ if ($config->has_attribute('error_mail_analyzer_function_select_list',
$fp)) {
$self->_run_analyzer($curproc, $error, $fp);
}
diff --git a/fml/lib/FML/Error/Analyze/histgram.pm b/fml/lib/FML/Error/Analyze/histgram.pm
index 0092d533..b7ccaedf 100644
--- a/fml/lib/FML/Error/Analyze/histgram.pm
+++ b/fml/lib/FML/Error/Analyze/histgram.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: histgram.pm,v 1.8 2004/02/15 04:38:32 fukachan Exp $
+# $FML: histgram.pm,v 1.9 2004/04/23 04:10:33 fukachan Exp $
#
package FML::Error::Analyze::histgram;
@@ -83,8 +83,8 @@ sub _histgram
my @removelist = ();
my $summary = {};
my $config = $curproc->config();
- my $limit = $config->{ error_analyzer_simple_count_limit } || 14;
- my $daylimit = $config->{ error_analyzer_day_limit } || 14;
+ my $limit = $config->{ error_mail_analyzer_simple_count_limit } || 14;
+ my $daylimit = $config->{ error_mail_analyzer_day_limit } || 14;
my $now = time; # unix time (seconds).
my $half_day = 12 * 3600 ; # 12 hours (seconds).
my $one_day = 24 * 3600 ; # 24 hours (seconds).
diff --git a/fml/lib/FML/Error/Analyze/simple_count.pm b/fml/lib/FML/Error/Analyze/simple_count.pm
index d8237a2c..c88f005d 100644
--- a/fml/lib/FML/Error/Analyze/simple_count.pm
+++ b/fml/lib/FML/Error/Analyze/simple_count.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: simple_count.pm,v 1.7 2004/02/15 04:38:32 fukachan Exp $
+# $FML: simple_count.pm,v 1.8 2004/04/23 04:10:33 fukachan Exp $
#
package FML::Error::Analyze::simple_count;
@@ -76,8 +76,8 @@ sub _simple_count
my @removelist = ();
my $summary = {};
my $config = $curproc->config();
- my $limit = $config->{ error_analyzer_simple_count_limit } || 5;
- my $daylimit = $config->{ error_analyzer_day_limit } || 14;
+ my $limit = $config->{ error_mail_analyzer_simple_count_limit } || 5;
+ my $daylimit = $config->{ error_mail_analyzer_day_limit } || 14;
my $now = time;
my $day = 24*3600;
my $threshold = $day * $daylimit;
diff --git a/fml/lib/FML/Error/Cache.pm b/fml/lib/FML/Error/Cache.pm
index d6f4a306..0100dc5f 100644
--- a/fml/lib/FML/Error/Cache.pm
+++ b/fml/lib/FML/Error/Cache.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: Cache.pm,v 1.20 2004/04/11 14:31:03 fukachan Exp $
+# $FML: Cache.pm,v 1.21 2004/04/23 04:10:33 fukachan Exp $
#
package FML::Error::Cache;
@@ -54,7 +54,7 @@ sub new
my ($type) = ref($self) || $self;
my $me = { _curproc => $curproc };
my $config = $curproc->config();
- my $db_dir = $config->{ error_analyzer_cache_dir };
+ my $db_dir = $config->{ error_mail_analyzer_cache_dir };
unless (-d $db_dir) {
$curproc->mkdir($db_dir, "mode=private");
@@ -230,13 +230,13 @@ sub _open_cache
my ($self) = @_;
my $curproc = $self->{ _curproc };
my $config = $curproc->config();
- my $dir = $config->{ error_analyzer_cache_dir };
+ my $dir = $config->{ error_mail_analyzer_cache_dir };
# parameters: but not used now.
my %db = ();
- my $type = $config->{ error_analyzer_cache_type };
- my $mode = $config->{ error_analyzer_cache_mode } || 'temporal';
- my $days = $config->{ error_analyzer_cache_size } || 14;
+ my $type = $config->{ error_mail_analyzer_cache_type };
+ my $mode = $config->{ error_mail_analyzer_cache_mode } || 'temporal';
+ my $days = $config->{ error_mail_analyzer_cache_size } || 14;
my $args = {
dir => $dir,
unit => 'day',
@@ -301,7 +301,7 @@ sub get_all_values_as_hash_ref
my ($self) = @_;
my $curproc = $self->{ _curproc };
my $config = $curproc->config();
- my $dir = $config->{ error_analyzer_cache_dir };
+ my $dir = $config->{ error_mail_analyzer_cache_dir };
use Tie::JournaledDir;
my $obj = new Tie::JournaledDir { dir => $dir };
diff --git a/fml/lib/FML/Error.pm b/fml/lib/FML/Error.pm
index eb693c2d..a03d16fa 100644
--- a/fml/lib/FML/Error.pm
+++ b/fml/lib/FML/Error.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: Error.pm,v 1.29 2004/02/01 14:35:33 fukachan Exp $
+# $FML: Error.pm,v 1.30 2004/04/23 04:10:27 fukachan Exp $
#
package FML::Error;
@@ -52,7 +52,7 @@ sub new
my ($type) = ref($self) || $self;
my $me = { _curproc => $curproc };
my $config = $curproc->config();
- my $fp = $config->{ error_analyzer_function } || 'simple_count';
+ my $fp = $config->{ error_mail_analyzer_function } || 'simple_count';
# default analyzer function
set_analyzer_function($me, $fp);
@@ -71,7 +71,7 @@ functions.
# Descriptions: lock channel we should use to lock this object.
# Arguments: OBJ($self)
# Side Effects: lock "error_analyzer_cache_dir" channel
# Return Value: STR
sub get_lock_channel_name
{
@@ -197,9 +197,9 @@ sub add
open error message cache and analyze the data by the analyzer
function. The function is specified by $config->{
-error_analyzer_function }. Available functions are located in
+error_mail_analyzer_function }. Available functions are located in
C<FML::Error::Analyze>. C<simple_count> function is used by default
-if $config->{ error_analyzer_function } is unspecified.
+if $config->{ error_mail_analyzer_function } is unspecified.
=cut
@@ -71,7 +71,7 @@ functions.
# Descriptions: lock channel we should use to lock this object.
# Arguments: OBJ($self)
-# Side Effects: lock "error_analyzer_cache_dir" channel
+# Side Effects: lock "error_mail_analyzer_cache_dir" channel
# Return Value: STR
sub get_lock_channel_name